@@ -1,23 +1,9 @@
-/***************************************************************************
- *   This file is part of KDevelop                                         *
- *   Copyright 2007 Andreas Pakulat <apaku@gmx.de>                         *
- *   Copyright 2010-2011 Sven Brauch <svenbrauch@googlemail.com>           *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU Library General Public License as       *
- *   published by the Free Software Foundation; either version 2 of the    *
- *   License, or (at your option) any later version.                       *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU Library General Public     *
- *   License along with this program; if not, write to the                 *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Andreas Pakulat <apaku@gmx.de>
+    SPDX-FileCopyrightText: 2010-2011 Sven Brauch <svenbrauch@googlemail.com>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "astbuilder.h"
 #include "ast.h"
@@ -61,10 +47,8 @@ QString PyUnicodeObjectToQString(PyObject* obj) {
             return QString::fromUtf16(PyUnicode_2BYTE_DATA(str), length);
         case PyUnicode_4BYTE_KIND:
             return QString::fromUcs4(PyUnicode_4BYTE_DATA(str), length);
-        case PyUnicode_WCHAR_KIND:
-            qWarning("PyUnicode_KIND(%p) returned PyUnicode_WCHAR_KIND, this should not happen!", (void*)str);
-            return QString::fromWCharArray(PyUnicode_AS_UNICODE(str), length);
     }
+    qCritical("PyUnicode_KIND(%p) returned an unexpected value, this should not happen!", (void*)str);
     Q_UNREACHABLE();
 }
 
@@ -104,7 +88,7 @@ CodeAst::Ptr AstBuilder::parse(const QUrl& filename, QString &contents)
 #if PYTHON_VERSION >= QT_VERSION_CHECK(3, 8, 0)
     PyCompilerFlags flags;
     flags.cf_flags = PyCF_SOURCE_IS_UTF8 | PyCF_IGNORE_COOKIE | PyCF_ONLY_AST;
-    flags.cf_feature_version = 7;
+    flags.cf_feature_version = PYTHON_VERSION_MINOR;
 #else
     PyCompilerFlags flags = {PyCF_SOURCE_IS_UTF8 | PyCF_IGNORE_COOKIE};
 #endif
